@@ -74,16 +74,14 @@ G_GNUC_EXTENSION typedef unsigned long long guint64;
 #define GLIB_SIZEOF_SIZE_T 4
 #define GLIB_SIZEOF_SSIZE_T 4
 
-typedef signed long gssize;
-typedef unsigned long gsize;
-#define G_GSIZE_MODIFIER "l"
-#define G_GSSIZE_MODIFIER "l"
-#define G_GSIZE_FORMAT "lu"
-#define G_GSSIZE_FORMAT "li"
+#define G_GSIZE_MODIFIER "z"
+#define G_GSSIZE_MODIFIER "z"
+#define G_GSIZE_FORMAT "zu"
+#define G_GSSIZE_FORMAT "zi"
 
-#define G_MAXSIZE	G_MAXULONG
-#define G_MINSSIZE	G_MINLONG
-#define G_MAXSSIZE	G_MAXLONG
+#define G_MAXSIZE	G_MAXUINT
+#define G_MINSSIZE	G_MININT
+#define G_MAXSSIZE	G_MAXINT
 
 typedef gint64 goffset;
 #define G_MINOFFSET	G_MININT64
@@ -114,8 +112,8 @@ typedef unsigned int guintptr;
 #endif
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 58
-#define GLIB_MICRO_VERSION 3
+#define GLIB_MINOR_VERSION 60
+#define GLIB_MICRO_VERSION 6
 
 #define G_OS_UNIX
 
@@ -158,7 +156,7 @@ typedef unsigned int guintptr;
 #define G_THREADS_ENABLED
 #define G_THREADS_IMPL_POSIX
 
-#undef G_ATOMIC_OP_MEMORY_BARRIER_NEEDED
+#define G_ATOMIC_OP_MEMORY_BARRIER_NEEDED
 #define G_ATOMIC_LOCK_FREE
 
 #define GINT16_TO_LE(val)	((gint16) (val))
